@@ -1,6 +1,6 @@
 package Test::Whitespaces;
 {
-  $Test::Whitespaces::VERSION = '1.0.0';
+  $Test::Whitespaces::VERSION = '1.1.0';
 }
 
 # ABSTRACT: test source code for errors in whitespaces
@@ -497,35 +497,26 @@ Test::Whitespaces - test source code for errors in whitespaces
 
 =head1 VERSION
 
-version 1.0.0
+version 1.1.0
 
 =head1 SYNOPSIS
 
-In xt/whitespaces.t:
+In xt/whitespaces.t (read FAQ section to find out why it is better to place
+test file in xt directory):
 
     use Test::Whitespaces {
 
         # Directories to check all the files from
-        dirs => [ 'lib', 'bin', 't' ],
-
-        # Files to be checekd (if you don't need to check the whole dir)
-        files => [ 'README' ],
-
-        # Files that matches any of this regexp will not be checked
-        ignore => [ qr{\.bak$} ],
+        dirs => [
+            'bin',
+            'lib',
+            't',
+        ],
 
     };
 
-This test will check all the files specified. It will pretty print all the
-errors, so it is easy to undestand where is the problem.
-
-This modules ships with the script `L<whiter>` that can fix all errors.
-
-This module is also shipeed with the script `L<test_whitespaces>` that you can
-use to check source code without writing your custom test file.
-
-All parameters are optional, but you need to specify at least one file to
-check.
+The test will check all the files specified by parameters. It will pretty
+print all the errors, so it is easy to undestand where is the problem.
 
 =head1 DESCRIPTION
 
@@ -553,7 +544,20 @@ and write there:
 
     use Test::Whitespaces { dirs => ['lib'] };
 
-Full description of the parameters is written in the SYNOPSIS section.
+Here is the full list of all avaliable parameters:
+
+    use Test::Whitespaces {
+
+        # Directories to check all the files from
+        dirs => [ 'lib', 'bin', 't' ],
+
+        # Files to be checekd (if you don't need to check the whole dir)
+        files => [ 'README' ],
+
+        # Files that matches any of this regexp will not be checked
+        ignore => [ qr{\.bak$} ],
+
+    };
 
 This module does not check the files that are stored in the version control
 system directories (you remember, that .git, .svn and friends).
@@ -594,7 +598,20 @@ Unicode support was implemented that is needed for this module.
 Q: What is the logic for version numbering?
 
 A: Test::Whitespaces version numbers uses Semantic Versioning standart.
-Please visit http://semver.org/ to find out all about this great thing.
+Please visit L<http://semver.org/> to find out all about this great thing.
+
+Q: Why is it recomended to put test file in xt directory?
+
+I recomend create test file as xt/whitespaces.t, not t/whitespaces.t.
+Directory `t` stores all the tests that will be run when the user installs
+module from CPAN. If you add testing whitespaces of the module to the `t`
+directory you will need to add dependency Test::Whitespaces to your module.
+But checking whitespaces does matter for the module author, and does not
+matter for the module user. I think that we should simplify module user life
+and not to oblige the user to install Test::Whitespaces. Directory `xt` is for
+extened tests. That tests are run by the module author, but are not run when
+the user installs module from CPAN. So xt directory is the perfect place to
+store file that checks whitespaces.
 
 =head1 SEE ALSO
 
